@@ -10,8 +10,8 @@ from threading import Thread, Event
 from .job import NumerousBaseJob, ExitCode
 from .errors import tb_str
 from numerous_cli.client import get_client
-from numerous_api_client.client import NumerousClient
-from numerous_api_client.client.numerous_client import ScenarioStatus
+from numerous.client import NumerousClient
+from numerous.client.numerous_client import ScenarioStatus
 
 VERSION = version('numerous_image_tools')
 APPVERSION = os.getenv('APPVERSION', "?")
@@ -48,6 +48,7 @@ class NumerousApp():
         self.logger.setLevel(level=log_level)
         self.model_folder = model_folder
         self.numerous_job = numerous_job
+        self.result = None
 
         self.setup_scenario()
 
@@ -126,6 +127,7 @@ class NumerousApp():
         self.logger.info(f"{self.appname} stopped")
         self.logger.info("Main thread stopped gracefully")
 
+        return self.result
 
 def checkpoint(tnow, tlast, interval=60):
     dt=datetime.timedelta(minutes=interval)
@@ -134,7 +136,8 @@ def checkpoint(tnow, tlast, interval=60):
     else:
         return False
 
-def run_job(numerous_job=None, appname=None, max_restarts=0, model_folder="models"):
+def run_job(numerous_job=None, appname=None, max_restarts=0, model_folder="models", working_folder="tmp",
+            reset_job=None):
     """
     Runs the simulation job with the model located in model_folder_name. Handles all events.
     """
@@ -151,8 +154,13 @@ def run_job(numerous_job=None, appname=None, max_restarts=0, model_folder="model
     signal.signal(signal.SIGTERM, handler)
 
     nc = None
+    app = None
+
     try:
-        RESET_JOB = os.getenv('RESET_JOB', 'False') == "True"
+        if reset_job is None:
+            RESET_JOB = os.getenv('RESET_JOB', 'False') == "True"
+        else:
+            RESET_JOB = reset_job
 
         if local:
             nc = get_client(reset_job=RESET_JOB)
@@ -168,6 +176,10 @@ def run_job(numerous_job=None, appname=None, max_restarts=0, model_folder="model
 
         logger.info(f"Welcome to numerous image tools. Base version {VERSION} - app {appname}")
 
+        #Change the working folder, so generated and downloaded files do not go in root of project
+        os.makedirs(working_folder, exist_ok=True)
+        os.chdir(working_folder)
+
         app = NumerousApp(numerous_client=nc, appname=appname,
                           max_restarts=max_restarts, numerous_job=numerous_job, model_folder=model_folder)
 
@@ -190,6 +202,11 @@ def run_job(numerous_job=None, appname=None, max_restarts=0, model_folder="model
         if nc is not None:
             nc.close()
 
+        if app:
+            #Return the result of the app
+            return app.result
+
+    return
 
 
 
